@@ -30,6 +30,20 @@ monthname = [None,
              'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec']
              
 
+def parse_address(host, port=None, default_port=8000):
+    if host.startswith("unix:"):
+        return host.split("unix:")[1]
+        
+    if not port:
+        if ':' in host:
+            host, port = host.split(':', 1)
+            if not port.isdigit():
+                raise RuntimeError("%r is not a valid port number." % port)
+            port = int(port)
+        else:
+            port = default_port
+    return (host, int(port))
+    
 def get_maxfd():
     maxfd = resource.getrlimit(resource.RLIMIT_NOFILE)[1]
     if (maxfd == resource.RLIM_INFINITY):
@@ -149,3 +163,12 @@ def http_date(timestamp=None):
             day, monthname[month], year,
             hh, mm, ss)
     return s
+    
+def to_bytestring(s):
+    """ convert to bytestring an unicode """
+    if not isinstance(s, basestring):
+        return s
+    if isinstance(s, unicode):
+        return s.encode('utf-8')
+    else:
+        return s
